@@ -4,6 +4,7 @@ from .redis import RedisService
 from .task import TaskService
 from .mail import MailService
 from .prometheus import PrometheusService
+from .elastic import ElasticService
 from .meta import MetaService
 
 __all__ = [
@@ -16,6 +17,7 @@ __all__ = [
     "TaskService",
     "MailService",
     "PrometheusService",
+    "ElasticService",
     "MetaService",
     "Kube",
 ]
