@@ -10,6 +10,7 @@ import types
 import base64
 import re
 import json
+import sys
 import functools
 import traceback
 import inspect
@@ -86,6 +87,10 @@ def print_stack_to_log():
     log_var_out(tb)
 
 
+def exc_stack_as_str_list():
+    return traceback.format_exception(*sys.exc_info())
+
+
 uuid_re = re.compile(
     "([a-f0-9]{8}-?[a-f0-9]{4}-?4[a-f0-9]{3}-?[89aAbB][a-f0-9]{3}-?[a-f0-9]{12})"
 )
